@@ -16,7 +16,8 @@ const mattermostStrategy = new OAuthStrategy({
   tokenURL: config.mattermost.baseURL + '/oauth/access_token',
   clientID: config.mattermost.clientID,
   clientSecret: config.mattermost.clientSecret,
-  callbackURL: config.serverURL + '/auth/mattermost/callback'
+  callbackURL: config.serverURL + '/auth/mattermost/callback',
+  state: true
 }, passportGeneralCallback)
 
 mattermostStrategy.userProfile = (accessToken, done) => {
